@@ -3,5 +3,7 @@ separate_arguments <- function(arglist){
         return(list(unamed = arglist, named = list()))
     }
     idx <- names(arglist) != ""
-    return(list(unamed = arglist[!idx], named = arglist[idx]))
+    unamed <- arglist[!idx]
+    names(unamed) <- NULL
+    return(list(unamed = unamed, named = arglist[idx]))
 }
